@@ -15,10 +15,6 @@ extern crate jwalk;
 extern crate nom;
 extern crate petgraph;
 
-#[cfg(test)] // <-- not needed in integration tests
-#[macro_use]
-extern crate spectral;
-
 #[cfg(test)] // <-- not needed in integration tests
 extern crate rstest;
 
@@ -60,7 +56,9 @@ pub fn parse<'a>(consumer: &mut dyn Consume, contents: &'a str) -> Option<Soluti
 pub fn scan(path: &str, extension: &str, consumer: &mut dyn Consume) -> usize {
     let parallelism = Parallelism::RayonNewPool(num_cpus::get_physical());
 
-    let iter = WalkDir::new(path)
+    let root = decorate_path(path);
+
+    let iter = WalkDir::new(root)
         .skip_hidden(false)
         .follow_links(false)
         .parallelism(parallelism);
@@ -82,3 +80,59 @@ pub fn scan(path: &str, extension: &str, consumer: &mut dyn Consume) -> usize {
         .inspect(|fp| parse_file(fp, consumer))
         .count()
 }
+
+/// On Windows added trailing back slash \ if volume and colon passed so as to paths look more pleasant
+#[cfg(target_os = "windows")]
+fn decorate_path(path: &str) -> String {
+    if path.len() == 2 && path.ends_with(':') {
+        format!("{}\\", path)
+    } else {
+        String::from(path)
+    }
+}
+
+/// On Unix just passthrough as is
+#[cfg(not(target_os = "windows"))]
+fn decorate_path(path: &str) -> String {
+    String::from(path)
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use rstest::*;
+
+    #[cfg(not(target_os = "windows"))]
+    #[rstest]
+    #[case("", "")]
+    #[case("/", "/")]
+    #[case("/home", "/home")]
+    #[case("d:", "d:")]
+    #[trace]
+    fn decorate_path_tests(#[case] raw_path: &str, #[case] expected: &str) {
+        // Arrange
+
+        // Act
+        let actual = decorate_path(raw_path);
+
+        // Assert
+        assert_eq!(actual, expected);
+    }
+
+    #[cfg(target_os = "windows")]
+    #[rstest]
+    #[case("", "")]
+    #[case("/", "/")]
+    #[case("d:", "d:\\")]
+    #[case("dd:", "dd:")]
+    #[trace]
+    fn decorate_path_tests(#[case] raw_path: &str, #[case] expected: &str) {
+        // Arrange
+
+        // Act
+        let actual = decorate_path(raw_path);
+
+        // Assert
+        assert_eq!(actual, expected);
+    }
+}
