@@ -107,7 +107,7 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     .group_by(|x| x.project_id)
                     .into_iter()
                     .map(|(pid, project_configs)| {
-                        let c = project_configs.map(|c| c.configs).flatten().collect();
+                        let c = project_configs.flat_map(|c| c.configs).collect();
                         ProjectConfigs::from_id_and_configs(pid, c)
                     })
                     .collect::<Vec<ProjectConfigs<'input>>>();
@@ -120,7 +120,7 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     .group_by(|x| x.project_id)
                     .into_iter()
                     .map(|(pid, project_configs)| {
-                        let c = project_configs.map(|c| c.configs).flatten().collect();
+                        let c = project_configs.flat_map(|c| c.configs).collect();
                         ProjectConfigs::from_id_and_configs(pid, c)
                     })
                     .collect::<Vec<ProjectConfigs<'input>>>();
@@ -137,8 +137,7 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
 
                 let from_project_configurations = project_configs
                     .iter()
-                    .map(|pc| pc.configs.iter())
-                    .flatten()
+                    .flat_map(|pc| pc.configs.iter())
                     .filter(|c| solution_configurations.contains(c.config));
                 sol.solution_configs.extend(from_project_configurations);
 
@@ -162,7 +161,6 @@ mod tests {
     use crate::lex::Lexer;
     use petgraph::dot::{Config, Dot};
     use rstest::*;
-    use spectral::prelude::*;
 
     #[test]
     fn parse_str_debug() {
@@ -183,7 +181,7 @@ mod tests {
         let result = parse_str(content, false);
 
         // Assert
-        assert_that!(result).is_none();
+        assert!(result.is_none());
     }
 
     #[test]
@@ -192,13 +190,13 @@ mod tests {
         let result = parse_str(REAL_SOLUTION, false);
 
         // Assert
-        assert_that!(result).is_some();
+        assert!(result.is_some());
         let solution = result.unwrap();
-        assert_that!(solution.projects.len()).is_equal_to(10);
-        assert_that!(solution.dependencies.node_count()).is_equal_to(10);
-        assert_that!(solution.dependencies.edge_count()).is_equal_to(4);
-        assert_that!(solution.format).is_equal_to("12.00");
-        assert_that!(solution.product).is_equal_to("Visual Studio 15");
+        assert_eq!(solution.projects.len(), 10);
+        assert_eq!(solution.dependencies.node_count(), 10);
+        assert_eq!(solution.dependencies.edge_count(), 4);
+        assert_eq!(solution.format, "12.00");
+        assert_eq!(solution.product, "Visual Studio 15");
         println!(
             "{:?}",
             Dot::with_config(&solution.dependencies, &[Config::EdgeNoLabel])
@@ -217,7 +215,7 @@ mod tests {
         let result = parse_str(&sln, false);
 
         // Assert
-        assert_that!(&result).is_some();
+        assert!(result.is_some());
     }
 
     #[test]
@@ -229,7 +227,7 @@ mod tests {
         let result = parse_str(sln, false);
 
         // Assert
-        assert_that!(&result).is_some();
+        assert!(result.is_some());
     }
 
     #[test]
@@ -260,7 +258,7 @@ EndGlobal
         let sln = parse_str(VERSION8_SOLUTION, false);
 
         // Assert
-        assert_that!(sln).is_some();
+        assert!(sln.is_some());
     }
 
     #[test]
@@ -279,7 +277,7 @@ EndGlobal
         let sln = parse_str(APR_SOLUTION, false);
 
         // Assert
-        assert_that!(sln).is_some();
+        assert!(sln.is_some());
     }
 
     #[test]
@@ -290,7 +288,7 @@ EndGlobal
         let sln = parse_str(APR_SOLUTION, true);
 
         // Assert
-        assert_that!(sln).is_none();
+        assert!(sln.is_none());
     }
 
     #[test]
